/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ThumbsDown.
 *
 * The Initial Developer of the Original Code is
 * Atte Kemppilä.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */


function WrappedPage() // extend WizardPage
{
    var depends = "images script";
    WizardPage.call(this, depends);
}

WrappedPage.prototype =
{
    get type()      { return $("rgroup_wrappedType"); },
    get typeValue() { return parseInt(this.type.value); },
    
    get id()     { return $("tbox_wrappedExpr_id"); },
    get regexp() { return $("tbox_wrappedExpr_regexp"); },
    
    onPageShow: function()
    {
        if (this.firstRun)
            $("col_wrapped_label").style.width = _("css.wrappedLabelColumn.width");
        
        // populate listbox
        if (this.dirty.images)
        {
            var rlbox = $("rlbox_wrapped");
            while (rlbox.itemCount > 0)
                rlbox.removeItemAt(0);
            for each (var thumbnail in model.images)
                rlbox.appendItem(thumbnail.target.image.link);
        }
        
        if (this.dirty.images || this.dirty.script)
        {
            var id = scriptWizard.getWrappedId(model.images);
            var regexp = scriptWizard.getWrappedRegExp(model.images);
            
            var script = model.script;
            if (script && (script.type != TYPE_WRAPPED))
                script = null;
            
            if (script)
            {
                switch (script.subType)
                {
                    case TYPE_WRAPPED_ID:
                        // not using script.wrappedExpr here in case id != wrappedExpr (new != old)
                        id = id;
                        break;
                    case TYPE_WRAPPED_REGEXP:
                        regexp = script.wrappedExpr;
                        break;
                }
                
                this.type.value = (id ? script.wrappedType : TYPE_WRAPPED_REGEXP);
            }
            else
                this.type.value = (id ? TYPE_WRAPPED_ID : TYPE_WRAPPED_REGEXP);
            
            this.regexp.defaultValue = regexp;
            this.regexp.reset();
            
            if (id)
                this.id.value = id;
            else
                // disable sub-type 'id' radio button if images have no ids (or they are not equal)
                this.type.firstChild.disabled = true;
        }
        
        if (this.dirty.page)
        {
            this._updateButtons();
            this._updateRows();
            this._updateRegExp();
        }
    },
    
    onTypeSelect: function()
    {
        this._updateButtons();
        this._updateRows();
        this._updateRegExp();
    },
    
    onRegExpInput: function()
    {
        if (this.updateTimer)
            this.updateTimer.cancel();
        
        this.updateTimer = callLater(INPUT_DELAY, this, this._updateRegExp);
        
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    resetRegExp: function()
    {
        this.regexp.reset();
        this._updateRegExp();
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    canAdvance: function()
    {
        if (this.updateTimer)
            return false;
        
        return $("rlbox_wrapped").match;
    },
    
    _updateButtons: function()
    {
        $("btn_wrappedExpr_regexp_reset").disabled = (this.regexp.value == this.regexp.defaultValue);
    },
    
    _updateRows: function()
    {
        this.id.parentNode.parentNode.hidden = (this.typeValue != TYPE_WRAPPED_ID);
        this.regexp.parentNode.parentNode.hidden = (this.typeValue != TYPE_WRAPPED_REGEXP);
    },
    
    _updateRegExp: function()
    {
        if (page != pages.wrapped)
            return;
        
        if (this.updateTimer)
        {
            this.updateTimer.cancel();
            delete this.updateTimer;
        }
        
        $("rlbox_wrapped").pattern = ((this.typeValue == TYPE_WRAPPED_REGEXP) ? "^" + this.regexp.value + "$" : ".*");
        
        wizard.updateWizardButtons();
    },
    
    onPageAdvanced: function()
    {
        model.type = TYPE_WRAPPED;
        model.wrappedType = this.typeValue;
        model.wrappedExpr = ((this.typeValue == TYPE_WRAPPED_REGEXP) ? this.regexp.value : this.id.value);
        return wizard.advance("script");
    }
}

extend(WrappedPage, WizardPage);

pages.wrapped = new WrappedPage();
